﻿using System.Data;
using System.Linq;
using System.Drawing;
using System.Windows.Forms;
using RadGridView.Properties;
using Telerik.WinControls;
using Telerik.WinControls.UI;

namespace RadGridView
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

	        var dataTable = GetDataTable();
            this.radGridView1.DataSource = dataTable;

            this.radGridView1.Relations.AddSelfReference(this.radGridView1.MasterTemplate, "Id", "IdParent");
            
            ConfigureGrid();

            var columnGroupsViewDefinition = GetColumnGroupsViewDefinition();
            this.radGridView1.ViewDefinition = columnGroupsViewDefinition;
        }

        private DataTable GetDataTable()
        {
            var result = new DataTable();
            result.Columns.Add("Id", typeof(int));
            result.Columns.Add("Name", typeof(string));
            result.Columns.Add("Surname", typeof(string));
            result.Columns.Add("Country", typeof(string));
            result.Columns.Add("Team", typeof(string));
            result.Columns.Add("IdParent", typeof(int));

            result.Rows.Add(1, "Karim", "Benzema", "Francia", "Real Madrid", -1);
            result.Rows.Add(2, "Cristiano", "Ronaldo", "Portugal", "Real Madrid", -1);
            result.Rows.Add(3, "Alvaro", "Arbeloa", "España", "Real Madrid", -1);
            result.Rows.Add(4, "Sergio", "Ramos", "España", "Real Madrid", -1);

            result.Rows.Add(6, "Toni", "Kross", "Alemania", "Real Madrid", 2);
            result.Rows.Add(7, "Gareth", "Bale", "Gales", "Real Madrid", 2);

            result.Rows.Add(8, "Iker", "Casillas", "España", "Real Madrid", 4);
            result.Rows.Add(9, "Sergio", "Busquets", "España", "Barcelona", 4);

	        return result;
        }        

        private ColumnGroupsViewDefinition GetColumnGroupsViewDefinition()
        {
            var result = new ColumnGroupsViewDefinition();

            result.ColumnGroups.Add(new GridViewColumnGroup("Player"));
            result.ColumnGroups[0].Rows.Add(new GridViewColumnGroupRow());
            result.ColumnGroups[0].Rows[0].Columns.Add(this.radGridView1.Columns["Name"]);
            result.ColumnGroups[0].Rows[0].Columns.Add(this.radGridView1.Columns["Surname"]);
            result.ColumnGroups[0].Rows[0].Columns.Add(this.radGridView1.Columns["Country"]);

            result.ColumnGroups.Add(new GridViewColumnGroup(string.Empty));
            result.ColumnGroups[1].Rows.Add(new GridViewColumnGroupRow());
            result.ColumnGroups[1].Rows.Add(new GridViewColumnGroupRow());
            result.ColumnGroups[1].Rows[0].Columns.Add(this.radGridView1.Columns["Team"]);

            return result;
        }

        private void ConfigureGrid()
        {
            foreach (var columna in this.radGridView1.Columns)
            {
                if (columna.FieldName == "Id" || columna.FieldName == "IdParent")
                {
                    columna.IsVisible = false;
                }
            }

            this.radGridView1.AutoSizeColumnsMode = GridViewAutoSizeColumnsMode.Fill;
            this.radGridView1.ReadOnly = true;
            this.radGridView1.BackColor = Color.White;
            this.radGridView1.EnableAlternatingRowColor = false;
            this.radGridView1.Visible = true;
            this.radGridView1.SelectionMode = GridViewSelectionMode.FullRowSelect;
            this.radGridView1.MultiSelect = false;
        }

        private void radGridView1_CellFormatting(object sender, CellFormattingEventArgs e)
        {
            if (e.CellElement != null)
            {
                var insertImageEpigrafe = e.Row.Index > -1 && e.Row.HierarchyLevel == 0 && e.Column.Name == "Name";
                if (insertImageEpigrafe)
                {
                    if (this.radGridView1.Rows[e.Row.Index].ChildRows.Any())
                    {
                        e.CellElement.Image = e.Row.IsExpanded ? Resources.ExpandTrue : Resources.ExpandFalse;
                    }
                    else
                    {
                        e.CellElement.Image = Resources.Blanco;
                    }
                    e.CellElement.ImageAlignment = ContentAlignment.MiddleLeft;
                    e.CellElement.TextImageRelation = TextImageRelation.ImageBeforeText;
                }

                var insertImageSociedad = e.Row.Index > -1 && e.Row.HierarchyLevel != 0 && e.Column.Name == "Name";
                if (insertImageSociedad)
                {
                    e.CellElement.Image = Resources.DobleBlanco;
                    e.CellElement.ImageAlignment = ContentAlignment.MiddleLeft;
                    e.CellElement.TextImageRelation = TextImageRelation.ImageBeforeText;
                }

                if (!insertImageEpigrafe && !insertImageSociedad)
                {
                    e.CellElement.ResetValue(LightVisualElement.ImageProperty, ValueResetFlags.Local);
                    e.CellElement.ResetValue(LightVisualElement.ImageAlignmentProperty, ValueResetFlags.Local);
                    e.CellElement.ResetValue(LightVisualElement.TextImageRelationProperty, ValueResetFlags.Local);
                }
            }
        }

        private void radGridView1_CellClick(object sender, GridViewCellEventArgs e)
        {
            if (e.Row.Index > -1 && e.Row.HierarchyLevel == 0 && e.Column.Name == "Name")
            {
                e.Row.IsExpanded = !e.Row.IsExpanded;
            }
        }
    }
}
